summaryrefslogtreecommitdiffstats
path: root/kviewshell/pageView.h
diff options
context:
space:
mode:
Diffstat (limited to 'kviewshell/pageView.h')
-rw-r--r--kviewshell/pageView.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kviewshell/pageView.h b/kviewshell/pageView.h
index 637a7e23..14b6fab2 100644
--- a/kviewshell/pageView.h
+++ b/kviewshell/pageView.h
@@ -106,8 +106,8 @@ public slots:
/** Turn the scrollbars on/off. */
void slotShowScrollbars(bool);
- /** Set tqlayout of the page widgets according to the current viewmode and zoomlevel.
- Set zoomChanged = true if the the tqlayout needs updateing because the zoomlevel has changed. */
+ /** Set layout of the page widgets according to the current viewmode and zoomlevel.
+ Set zoomChanged = true if the the layout needs updateing because the zoomlevel has changed. */
void layoutPages(bool zoomChanged = false);
void slotEnableMoveTool(bool enable);